@@ -15,6 +15,7 @@ from neutronics_material_maker import (
     make_fispact_material,
     make_serpent_material,
     make_mcnp_material,
+    make_shift_material,
     material_dict,
     zaid_to_isotope,
 )
@@ -193,6 +194,7 @@ class Material:
         self.openmc_material = None
         self.serpent_material = None
         self.mcnp_material = None
+        self.shift_material = None
         self.fispact_material = None
         self.list_of_fractions = None
 
@@ -288,6 +290,7 @@ class Material:
         Returns a MCNP version of the Material. Requires the
         Material.material_id to be set. Decimal places can be controlled with
         the Material.decimal_places attribute.
+        Temperature of the material is set as 273K.
 
         :type: str
         """
@@ -298,6 +301,22 @@ class Material:
     def mcnp_material(self, value):
         self._mcnp_material = value
 
+    @property
+    def shift_material(self):
+        """
+        Returns a Shift version of the Material. Requires the
+        Material.material_id to be set. Decimal places can be controlled with
+        the Material.deicmal_places attribute.
+
+        :type: str
+        """
+        self._shift_material = make_shift_material(self)
+        return self._shift_material
+
+    @shift_material.setter
+    def shift_material(self, value):
+        self._shift_material = value
+
     @property
     def fispact_material(self):
         """
