@@ -88,6 +88,16 @@ class test_object_properties(unittest.TestCase):
 
             assert isinstance(test_mat.mcnp_material, str)
 
+    def test_dictionary_of_materials_makes_shift_materials(self):
+
+        for mat in nmm.AvailableMaterials().keys():
+            print(mat)
+            test_mat = nmm.Material(
+                mat, temperature_in_K=300, pressure_in_Pa=5e6, material_id=1
+            )
+
+            assert isinstance(test_mat.shift_material, str)
+
     def test_dictionary_of_materials_makes_fispact_materials(self):
 
         for mat in nmm.AvailableMaterials().keys():
